@@ -1,6 +1,6 @@
 #' @export
-group_by.tbl_svy <- function(.data, ..., add = FALSE, .drop = dplyr::group_by_drop_default(.data)) {
-  .data$variables <- group_by(.data$variables, ..., add = add, .drop = .drop)
+group_by.tbl_svy <- function(.data, ..., .add = FALSE, .drop = dplyr::group_by_drop_default(.data)) {
+  .data$variables <- group_by(.data$variables, ..., .add = .add, .drop = .drop)
   class(.data) <- c("grouped_svy", class(.data))
   .data
 }
@@ -8,7 +8,7 @@ group_by.tbl_svy <- function(.data, ..., add = FALSE, .drop = dplyr::group_by_dr
 #' @export
 group_by_.tbl_svy <- function(.data, ..., .dots, add = FALSE, .drop = dplyr::group_by_drop_default(.data)) {
   dots <- compat_lazy_dots(.dots, caller_env(), ...)
-  group_by(.data, !!!dots, add = add)
+  group_by(.data, !!!dots, add = add, .drop = .drop)
 }
 
 #' @export
